#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses

import window
import events
from helper import formattime


class playerwin(window.window):
    def __init__(self, screen, h, w, y, x, colors, channel, player, keybindings):
        self.song = None
        self.time = 0
        self.player = player
        self.keybindings = keybindings["global"]
        window.window.__init__(self, screen, h, w, y, x,
                               colors,
                               _("Playback Info"))

        # we don't want to have the focus
        self.panel.bottom()
        
        channel.subscribe(events.playbackinfochanged, self.playbackinfochanged)
        channel.subscribe(events.keypressed, self.keypressed)
        self.update()

    def playbackinfochanged(self, event):
        if event.playbackinfo.player is self.player:
            self.song = event.playbackinfo.song
            if self.song:
                self.settitle("%s%s - %s" % (event.playbackinfo.iscrossfading() and "-> " or "",
                                             self.song.artist,
                                             self.song.title))
            else:
                self.settitle(_("Playback Info"))
            self.time = event.playbackinfo.time
            self.update()

    def keypressed(self, event):
        key = event.key
        if key in self.keybindings["playerstart"]:
            events.hub.notify(events.playerstart(self.player))
        elif key in self.keybindings["playernextsong"]:
            events.hub.notify(events.playerforward(self.player))   
        elif key in self.keybindings["playerstop"]:
            events.hub.notify(events.playerstop(self.player))   
        else:
            return
        raise events.TerminateEventProcessing
        
    def update(self):
        window.window.update(self)
        self.win.addstr(1, 1, " "*self.iw)
        if self.song:
            self.win.move(1, 1)
            s1 = _("Time:")
            s2 = " %s/%s " % (formattime(self.time), formattime(self.song.length))
            self.win.addstr(s1, self.colors["description"])
            self.win.addstr(s2, self.colors["content"])
            
            barlen = self.iw-len(s1)-len(s2)
            try:
                percentplayed = int(barlen*self.time/self.song.length)
            except ZeroDivisionError:
                percentplayed = 0
            self.win.addstr("#"*(percentplayed), self.colors["progressbarhigh"])
            self.win.addstr("#"*(barlen-percentplayed), self.colors["progressbar"])
